@@ -29,7 +29,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2019  Craig Barratt
+#   Copyright (C) 2001-2020  Craig Barratt
 #
 #   See https://backuppc.github.io/backuppc
 #
@@ -91,8 +91,8 @@ $Conf{UmaskMode} = 027;
 
 #
 # Times at which we wake up, check all the PCs, and schedule necessary
-# backups.  Times are measured in hours since midnight.  Can be
-# fractional if necessary (eg: 4.25 means 4:15am).
+# backups.  Times are measured in hours since midnight local time.
+# Can be fractional if necessary (eg: 4.25 means 4:15am).
 #
 # If the hosts you are backing up are always connected to the network
 # you might have only one or two wakeups each night.  This will keep
@@ -903,6 +903,26 @@ $Conf{ClientCharset} = '';
 #
 $Conf{ClientCharsetLegacy} = 'iso-8859-1';
 
+#
+# Optionally map the share name to a different path on the client when the
+# xfer program is run. This can be used if you create a snapshot on the client,
+# which has a different path to the real share name.  Or you could use simpler
+# names for the share instead of a path (eg: root, home, usr) and map them to
+# the real paths here.
+#
+# This should be a hash whose key is the share name used in $Conf{SmbShareName},
+# $Conf{TarShareName}, $Conf{RsyncShareName}, $Conf{FtpShareName}, and the
+# value is the string path name on the client.  When a backup or restore is
+# done, if there is no matching entry in $Conf{ClientShareName2Path}, or the
+# entry is empty, then the share name is not modified (so the default behavior
+# is unchanged).
+#
+# If you are using the rsyncd xfer method, then there is no need to use this
+# configuration setting (since rsyncd already supports mapping of share names
+# to paths in the client's rsyncd.conf).
+#
+$Conf{ClientShareName2Path} = { };
+
 ###########################################################################
 # Samba Configuration
 # (can be overwritten in the per-PC log file)
@@ -1189,6 +1209,9 @@ $Conf{RsyncBackupPCPath} = "/usr/share/backuppc/bin/rsync_bpc";
 # to just allow ssh via a low-privileged user, and use sudo
 # in $Conf{RsyncClientPath}.
 #
+# The setting should only have two entries: "-e" and
+# everything else; don't add additoinal array elements.
+#
 # This setting only matters if $Conf{XferMethod} = 'rsync'.
 #
 $Conf{RsyncSshArgs} = [
@@ -1233,24 +1256,6 @@ $Conf{RsyncdUserName} = '';
 #
 $Conf{RsyncdPasswd} = '';
 
-#
-# Additional arguments for a full rsync or rsyncd backup.
-#
-# The --checksum argument causes the client to send full-file checksum
-# for every file (meaning the client reads every file and computes the
-# checksum, which is sent with the file list).  On the server, rsync_bpc
-# will skip any files that have a matching full-file checksum, and size,
-# mtime and number of hardlinks.  Any file that has different attributes
-# will be updating using the block rsync algorithm.
-#
-# In V3, full backups applied the block rsync algorithm to every file,
-# which is a lot slower but a bit more conservative.  To get that
-# behavior, replace --checksum with --ignore-times.
-#
-$Conf{RsyncFullArgsExtra} = [
-            '--checksum',
-];
-
 #
 # Arguments to rsync for backup.  Do not edit the first set unless you
 # have a good understanding of rsync options.
@@ -1316,6 +1321,30 @@ $Conf{RsyncArgs} = [
 #
 $Conf{RsyncArgsExtra} = [];
 
+#
+# Additional arguments for a full rsync or rsyncd backup.
+#
+# The --checksum argument causes the client to send full-file checksum
+# for every file (meaning the client reads every file and computes the
+# checksum, which is sent with the file list).  On the server, rsync_bpc
+# will skip any files that have a matching full-file checksum, and size,
+# mtime and number of hardlinks.  Any file that has different attributes
+# will be updating using the block rsync algorithm.
+#
+# In V3, full backups applied the block rsync algorithm to every file,
+# which is a lot slower but a bit more conservative.  To get that
+# behavior, replace --checksum with --ignore-times.
+#
+$Conf{RsyncFullArgsExtra} = [
+            '--checksum',
+];
+
+#
+# Additional arguments for an incremental rsync or rsyncd backup.
+#
+$Conf{RsyncIncrArgsExtra} = [
+];
+
 #
 # Arguments to rsync for restore.  Do not edit the first set unless you
 # have a thorough understanding of how File::RsyncP works.
@@ -2244,6 +2273,7 @@ $Conf{CgiUserConfigEdit} = {
         ClientCharsetLegacy       => 1,
         ClientComment             => 1,
         ClientNameAlias           => 1,
+        ClientShareName2Path      => 1,
         ClientTimeout             => 1,
         CompressLevel             => 1,
         DumpPostShareCmd          => 0,
@@ -2299,6 +2329,7 @@ $Conf{CgiUserConfigEdit} = {
         RsyncdPasswd              => 1,
         RsyncdUserName            => 1,
         RsyncFullArgsExtra        => 1,
+        RsyncIncrArgsExtra        => 1,
         RsyncRestoreArgs          => 1,
         RsyncShareName            => 1,
         RsyncSshArgs              => 1,
